==> selenium-remote-driver-3.12.0-sources.jar: org/openqa/selenium/remote/session/W3CPlatformNameNormaliser.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.remote.session;

import static java.util.Collections.singleton;
import static java.util.Locale.ENGLISH;
import static org.openqa.selenium.remote.CapabilityType.PLATFORM_NAME;

import java.util.AbstractMap;
import java.util.Collection;
import java.util.Map;

public class W3CPlatformNameNormaliser implements CapabilityTransform {

  @Override
  public Collection<Map.Entry<String, Object>> apply(Map.Entry<String, Object> entry) {
    if (!PLATFORM_NAME.equals(entry.getKey())) {
      return singleton(entry);
    }

    return singleton(new AbstractMap.SimpleImmutableEntry<String, Object>(
        entry.getKey(),
        String.valueOf(entry.getValue()).toLowerCase(ENGLISH)));
  }
}

==> selenium-remote-driver-4.5.3-sources.jar: org/openqa/selenium/remote/session/W3CPlatformNameNormaliser.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.remote.session;

import static java.util.Collections.singleton;
import static java.util.Locale.ENGLISH;
import static org.openqa.selenium.remote.CapabilityType.PLATFORM_NAME;

import java.util.AbstractMap;
import java.util.Collection;
import java.util.Map;

public class W3CPlatformNameNormaliser implements CapabilityTransform {

  @Override
  public Collection<Map.Entry<String, Object>> apply(Map.Entry<String, Object> entry) {
    if (!PLATFORM_NAME.equals(entry.getKey())) {
      return singleton(entry);
    }

    return singleton(new AbstractMap.SimpleImmutableEntry<>(
      entry.getKey(),
      String.valueOf(entry.getValue()).toLowerCase(ENGLISH)));
  }
}
